use std::env;
use std::str::FromStr;
use std::net::Ipv4Addr;

// le a variable de entorno TEMPLATES para configurar o path ó directorio dos templates
pub fn env_templates_dir() -> String {
    match env::var_os("TEMPLATES") {
        Some(val) => val.into_string().unwrap(),
        None => "templates/".to_string(),
    }
}

// le a variable de entorno IP para configurar a ip de escoita
// por defecto 127.0.0.1
pub fn env_listen_ip() -> Ipv4Addr {
    match env::var_os("IP") {
        Some(val) => Ipv4Addr::from_str(val.to_str().unwrap()).unwrap(),
        None => Ipv4Addr::new(127, 0, 0, 1),
    }
}

// le a variable de entorno PORT para configurar o porto de escoita
// por defecto o 3000
pub fn env_listen_port() -> u16 {
    match env::var_os("PORT") {
        Some(val) => val.into_string().unwrap().parse::<u16>().unwrap(),
        None => 3000,
    }
}
