use axum::response::Html;
use serde::Serialize;
use rand::Rng;
use minijinja::render;
use std::fs;

#[derive(Serialize, Debug)]
struct PJ {
    nombre: String,
    fue: i32,
    agi: i32,
    men: i32,
    pg: i32,
    trasfondo: String,
    equipo: Vec<String>
}

#[derive(Serialize, Debug)]
struct Trasfondo {
    nombre: String,
    equipo: Vec<String>
}

pub async fn genera_pj() -> Html<String> {
    let trasf = trasfondo_random().await;
    let n =LIST_NOMBRES[rand::thread_rng().gen_range(0..72)].to_string();
    let a =LIST_APELLIDOS[rand::thread_rng().gen_range(0..36)].to_string();
    let pj = PJ {
        nombre: format!("{} {}", n, a),
        fue: rand::thread_rng().gen_range(3..19),
        agi: rand::thread_rng().gen_range(3..19),
        men: rand::thread_rng().gen_range(3..19),
        pg: rand::thread_rng().gen_range(1..7),
        trasfondo: trasf.nombre,
        equipo: trasf.equipo,
    };

    let path = format!("{}/personaje.html", itkg_lib::env_templates_dir());
    let template = fs::read_to_string(path).unwrap();
    let r = render!(&template, personaje => pj);
    Html(r)
}

async fn trasfondo_random() -> Trasfondo {

    let seleccionado = LIST_TRAS[rand::thread_rng().gen_range(0..20)];
    let partes: Vec<&str> = seleccionado.split(":").collect();

    let nome: String;
    let mut equip_strings = Vec::new();

    if partes.len() > 1 {
        // nome
        nome = partes[0].to_string();
        // equipo
        let equip: Vec<&str> = partes[1].split(".").collect();
        for e in equip {
            equip_strings.push(e.to_string()); // considerer borrar espacios iniciales e finales
        }
    } else {
        nome = "".to_string();
        equip_strings.push("".to_string());
    }

    Trasfondo {
        nombre: String::from(nome),
        equipo: equip_strings,
    }
}

//formato ->  nombre: equipo.equipo.equipo
const LIST_TRAS: [&str; 20] = [
    "Aristócrata: Pistola láser (d6). Dermo. Símbolo del cargo",
    "Soldado: Rifle blaster (d10, Voluminoso). Armadura ligera (1A). Sensor de explosivos",
    "Policía: Blaster (d8). Grilletes. Cigarros",
    "Cazarrecompensas: Blaster (d8). Armadura ligera (1A) y escudo (+1A). Rastreador y baliza",
    "Piloto: Pistola láser (d6). Granada(d8). Respirador",
    "Tecnólogo / Hacker: Pistola láser (d6). MiniPC. Dermo",
    "Mecánico / Ingeniero: Hacha de plasma (d8). Escudo (+1A). Bluebox. Gallo",
    "Explorador / Cazador: Arco de energía (d8). Trampa portátil",
    "Académico - Arqueólogo/Historiador: Daga (d4). Generador de hologramas. Piedra",
    "Académico - Científico: Dardos (d4). Toxina. Antitoxina",
    "Médico: Pistola láser (d6). Dermo. Kit médico",
    "Consejero / Psicólogo: Punzón plasma (d6). Holo-rorschach. Dermo",
    "Clérigo / Religioso / Monje: Espada de plasma (d8). Altavoz implantado",
    "Intérprete / Animador: Daga (d6). Click metamorfoseador. Pañuelo de seda",
    "Criminal (¡dinos de qué tipo!): Blaster (d8). Bluebox. Pata de cabra",
    "Mensajero en deslizador: Porra de energía (d6). Deslizador personal",
    "Funcionario: Daga (d4). Dermo. Pase gubernamental a punto de caducar",
    "Atleta (¡dinos de qué tipo!): Bate de vacío (d10, Voluminoso). Click acelerador",
    "Jugador / Tahur: Pistola láser (d6). Armadura ligera (1A). Baraja/dados/tabas",
    "Comerciante: Blaster de antebrazo (d6). 3 bombas. Botella de Ron",
];

const LIST_NOMBRES: [&str; 72] = [
"Adrian",
"Arashi",
"Asano",
"Branden",
"Charlie",
"Demenok",
"Ebinuma",
"Ferran",
"Henry",
"Hugo",
"Jamie",
"Josep",
"Kamari",
"Koshikawa",
"Marc",
"Michael",
"Nikulin",
"Pol",
"Polotentsev",
"Rabinovich",
"Salko",
"Samuel",
"Sazama",
"Silas",
"Smetanin",
"Suguro",
"Tony",
"Tristian",
"Uglichinin",
"Umeda",
"Unkovsky",
"Xabier",
"Yagi",
"Yamanami",
"Yoshimi",
"Zakai",
"Adara",
"Amira",
"Brantova",
"Chihoko",
"Chinatsu",
"Durchenka",
"Eiko",
"Elizabeth",
"Emma",
"Garina",
"Hisako",
"Inaho",
"Isabella",
"Kaho",
"Kalski",
"Kikyo",
"Kylie",
"Lilly",
"Lucille",
"Maleah",
"Martina",
"Nadeshiko",
"Nao",
"Nicole",
"Paola",
"Penkina",
"Ruth",
"Siyanova",
"Soraya",
"Suzume",
"Tashka",
"Taylor",
"Utzuki",
"Vanesa",
"Yulinka",
"Yureneva"
];

const LIST_APELLIDOS: [&str; 36] = [
"Albacete",
"Anderson",
"Arroyo",
"Bowen",
"Burks",
"Caballero",
"Carbonero",
"Chistau",
"Dmitrievich",
"Filippovich",
"Foster",
"Furutani",
"Hall",
"Huff",
"Ishikawa",
"Kelly",
"Lagos",
"Lowe",
"Martin",
"Maximovich",
"Mihara",
"Nagatsuka",
"Nakamura",
"Olegovich",
"Romanovich",
"Sáenz",
"Sakane",
"Sakuma",
"Semyonovich",
"Short",
"Sonoda",
"Stepanovich",
"Tejedor",
"Uchida",
"Verdugo",
"Vsevolodovich"
];
